<?php
declare(strict_types=1);

namespace Mollie\Api\Types;

class OrderLineUpdateOperationType
{
    public const ADD = 'add';

    public const CANCEL = 'cancel';

    public const UPDATE = 'update';
}
