<?php

namespace Mollie\Api\Types;

class BalanceTransferFrequency
{
    const DAILY = "daily";
    const TWICE_A_WEEK = "twice-a-week";
    const EVERY_MONDAY = "every-monday";
    const EVERY_TUESDAY = "every-tuesday";
    const EVERY_WEDNESDAY = "every-wednesday";
    const EVERY_THURSDAY = "every-thursday";
    const EVERY_FRIDAY = "every-friday";
    const EVERY_SATURDAY = "every-saturday";
    const EVERY_SUNDAY = "every-sunday";
    const TWICE_A_MONTH = "twice-a-month";
    const NEVER = "never";
}
